<?xml version="1.0" ?><!DOCTYPE TS><TS language="sr" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Дипин Прегледач Слика</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Верзија:</translation>
    </message>
</context>
<context>
    <name>AlbumBTContent</name>
    <message>
        <source>image</source>
        <translation>слика</translation>
    </message>
    <message>
        <source>images</source>
        <translation>слика</translation>
    </message>
    <message>
        <source>album</source>
        <translation>албум</translation>
    </message>
    <message>
        <source>albums</source>
        <translation>албума</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Управљај синхронизацијом</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Синхронизација:</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>У реду</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Нови албум</translation>
    </message>
    <message>
        <source>Unnamed</source>
        <translation>Неименовано</translation>
    </message>
</context>
<context>
    <name>AlbumDelegate</name>
    <message>
        <source>Recent imported</source>
        <translation>Недавно увезено</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Омиљено</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Are your sure to delete this album?</source>
        <translation>Заиста желите да обришете албум?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Обриши</translation>
    </message>
</context>
<context>
    <name>AlbumPanel</name>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Омиљено</translation>
    </message>
    <message>
        <source>Timeline</source>
        <translation>Временска линија</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Додај</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Можете додати директоријум за синхронизацију или превући слике на временску линију</translation>
    </message>
</context>
<context>
    <name>AlbumsView</name>
    <message>
        <source>Unnamed</source>
        <translation>Неименовано</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Прегледај</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Покретни приказ</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Преименуј</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копирај</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Обриши</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Дипин Прегледач Слика</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Слика</translation>
    </message>
</context>
<context>
    <name>DirImportDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>У реду</translation>
    </message>
    <message>
        <source>Are you sure to add the pictures to the album?</source>
        <translation>Заиста желите да додате слике у албум?</translation>
    </message>
    <message>
        <source>Sync and Create</source>
        <translation>Синхро. и направи</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Синхро.</translation>
    </message>
    <message>
        <source>Are you sure to add to the sync list and create the album named after this folder?</source>
        <translation>Желите ли да додате на листу синхронизације и направите албум именован по овој фасцикли?</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</source>
        <translation>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</translation>
    </message>
    <message>
        <source>Exported successfully</source>
        <translation>Успешно извезено</translation>
    </message>
    <message>
        <source>Failed to export</source>
        <translation>Извоз неуспешан</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Сачувај</translation>
    </message>
</context>
<context>
    <name>FileDeleteDialog</name>
    <message>
        <source>Are you sure to throw pictures to TRASH?</source>
        <translation>Сигурно желите да баците слике у СМЕЋЕ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Обриши</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Image info</source>
        <translation>Својства слике</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Датотека садржи више страница, молимо користите Evince да прегледате све странице.</translation>
    </message>
</context>
<context>
    <name>ImagesView</name>
    <message>
        <source>View</source>
        <translation>Прегледај</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Цео екран</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Покретни приказ</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Штампај</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копирај</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Копирај у бележницу</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Уклони из албума</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>У омиљено</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Из омиљеног</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Ротирај удесно</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Ротирај улево</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Постави као позадину</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Прикажи у управнику података</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Својства слике</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Додај</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Можете додати директоријум за синхронизацију или превући слике на временску линију</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Додај у албум</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Додај у нови албум</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Обриши</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Отвори директоријум</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Немате овлашћење да прегледате слику</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Име</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>Date photoed</source>
        <translation>Датум сликања</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Измењено</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation>Димензије</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Величина</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Опсег боја</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Режим експозиције</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Програм експозиције</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Трајање експозиције</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Блиц</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Бленда</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Жижна даљина</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ИСО</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Највећа бленда</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Режим мерача</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Баланс беле</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Компензација блица</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Модел апарата</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Модел сочива</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Без скалирања</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Прилагоди страницу слици</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Прилагоди слику страници</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Скалирај у:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Милиметри</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Сантиметри</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Инчи</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Позиција слике</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Скалирање</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Поставке слике</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation>Поставке слике</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Ролетне</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Клапна</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Клизање</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Прстен</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Одабери директоријум</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Синхронизација онемогућена за овај директоријум</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Додај фасциклу</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Управљање синхронизацијом директоријума</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>Листа диркторијума је празна</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Откажи синхро.</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Слике</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Уређај је уклоњен</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Овај директоријум више не постоји</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Рачунање...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Преглед слика</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Албум</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Подешавања</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Прегледај</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Цео екран</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Покретни приказ</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Окончај</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копирај</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Уклони из албума</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>У омиљено</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Из омиљеног</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Ротирај удесно</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Ротирај улево</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Постави као позадину</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Прикажи у управнику података</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Својства слике</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Претходно</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Следеће</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Претходни екран</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Следећи екран</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Нови албум</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Преименуј</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Помоћ</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Изађи</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Прикажи пречице</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Обриши</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Молимо унесите нову пречицу</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Пречице</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Преглед слике</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Албум</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Врати подразумевано</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Прегледај</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Цео екран</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Покретни приказ</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Окончај</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Штампај</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копирај</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Уклони из албума</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>У омиљено</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Из омиљеног</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Ротирај удесно</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Ротирај улево</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Постави као позадину</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Прикажи у управнику података</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Својства слике</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Нови албум</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Преименуј</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Обриши</translation>
    </message>
</context>
<context>
    <name>SlideShowPanel</name>
    <message>
        <source>End show</source>
        <translation>Окончај</translation>
    </message>
    <message>
        <source>Pause/Play</source>
        <translation>Пауза/Пусти</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Поставке покретног приказа</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Прелазни ефекти</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Трајање</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Трајање приказа</translation>
    </message>
    <message>
        <source>second</source>
        <translation>секунде</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Управљање сликама</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Омиљено</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 Размера</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Уклопи у прозор</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Ротирај улево</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Ротирај удесно</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Из омиљеног</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>У омиљено</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Обриши</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Нису пронађене датотеке са сликама</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Отвори слику</translation>
    </message>
</context>
<context>
    <name>TimelineBTContent</name>
    <message>
        <source>%1 image</source>
        <translation>%1 слика</translation>
    </message>
    <message>
        <source>%1 images</source>
        <translation>%1 слика/е</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Управљај синхронизацијом</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Синхронизација:</translation>
    </message>
</context>
<context>
    <name>TimelinePanel</name>
    <message>
        <source>Album</source>
        <translation>Албум</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Додај</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Можете додати директоријум за синхронизацију или превући слике на временску линију</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Додај у албум</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Додај у нови албум</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Прегледај</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Цео екран</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Покретни приказ</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Штампај</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копирај</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Копирај у бележницу</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>У омиљено</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Из омиљеног</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Ротирај удесно</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Ротирај улево</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Постави као позадину</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Прикажи у управнику података</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Својства слике</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Обриши</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Покретни приказ</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Ефекат</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Трајање</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Пречице</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Прегледај</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Албум</translation>
    </message>
</context>
<context>
    <name>TopAlbumTips</name>
    <message>
        <source>dd MMMM yyyy</source>
        <translation>dd MMMM yyyy</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Омиљено</translation>
    </message>
    <message>
        <source>Recent imported</source>
        <translation>Недавно увезено</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Нови албум</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Подешавања</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
        <translation>Дипин Прегледач Слика је модеран &amp; префињен управник слика.</translation>
    </message>
    <message>
        <source>It is featured with image management, image viewing and basic image editing.</source>
        <translation>Омогућава управљање, прегледање и основно уређивање слика.</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Тамна тема</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Дипин Прегледач Слика је алат за приказ слика са модерним сучељем и добрим перформансама.</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Временска линија</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Додај у албум</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Додај у нови албум</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Напусти цео екран</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Цео екран</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Покретни приказ</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Штампај</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копирај</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Копирај у бележницу</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Уклони из албума</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>У омиљено</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Из омиљеног</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Прикажи навигациони прозор</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Сакриј навигациони прозор</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Ротирај удесно</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Ротирај улево</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Постави као позадину</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Прикажи у управнику података</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Својства слике</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Обриши</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Отвори слику</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Све слике</translation>
    </message>
</context>
</TS>